@@ -9,6 +9,7 @@ export const preprocessingTechniques = [
                 options: [0, 1],
                 default: 0,
                 render: true,
+                optional: true,
             },
             {
                 name: "how",
@@ -16,11 +17,13 @@ export const preprocessingTechniques = [
                 options: ["any", "all"],
                 default: "any",
                 render: true,
+                optional: true,
             },
             {
                 name: "subset",
                 type: "columnList",
                 render: true,
+                optional: true,
             },
             {
                 name: "inplace",
@@ -28,6 +31,7 @@ export const preprocessingTechniques = [
                 options: [true, false],
                 default: false,
                 render: true,
+                optional: true,
             },
           ],
     },
@@ -37,11 +41,18 @@ export const preprocessingTechniques = [
         name: "Replace NAN values",
         value: "Replace NAN values",
         parameters: [
+          {
+            name: "column",
+            type: "columnName",   
+            render: true,
+            optional: false,
+          },
           {
             name: "missing_values",
             type: "any",    //int | float | str | np.nan| None |pandas.NA
             default: 'np.nan',
             render: true,
+            optional: true,
           },
           {
             name: "strategy",
@@ -49,12 +60,14 @@ export const preprocessingTechniques = [
             options: ['mean','median','most_frequent','constant'],
             default: 'mean',
             render: true,
+            optional: false,
           },
           {
             name: "fill_value",  //for 'constant' strategy
             type: "str | number",
             default: 'None',
             render: true,
+            optional: true, //check
           },
         ],
     },
@@ -66,23 +79,15 @@ export const preprocessingTechniques = [
             name: "labels",
             type: "columnList",   
             render: true,
+            optional: false,
           },
           {
             name: "axis",
             type: "select",
             options: [0, 1],
-            defaultValue: 0,
-            render: true,
-          },
-          {
-            name: "index",
-            type: "columnList",
-            render: true,
-          },
-          {
-            name: "columns",
-            type: "columnList",
+            defaultValue: 1,
             render: true,
+            optional: true,
           },
           {
             name: "inplace",
@@ -90,6 +95,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             defaultValue: false,
             render: true,
+            optional: true,
           },
           {
             name: "errors",
@@ -97,6 +103,7 @@ export const preprocessingTechniques = [
             options: ["ignore", "raise"],
             defaultValue: "raise",
             render: true,
+            optional: true,
           },
         ],
     },
@@ -108,6 +115,7 @@ export const preprocessingTechniques = [
             name: "columns",
             type: "columnList",
             render: true,
+            optional: false,
           },
         ],
     },
@@ -119,6 +127,7 @@ export const preprocessingTechniques = [
             name: "subset",
             type: "columnList",   
             render: true,
+            optional: true,
           },
           {
             name: "keep",
@@ -126,6 +135,7 @@ export const preprocessingTechniques = [
             options: ['first','last', false],
             default: 'first',
             render: true,
+            optional: true,
           },
           {
             name: "inplace",
@@ -133,6 +143,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             defaultValue: false,
             render: true,
+            optional: true,
           },
           {
             name: "ignore_index",
@@ -140,6 +151,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             defaultValue: false,
             render: true,
+            optional: true,
           },
         ],
     },
@@ -151,11 +163,29 @@ export const preprocessingTechniques = [
             name: "column",
             type: "columnName",
             render: true,
+            optional: false,
           },
           {
             name: "data type",
             type: "string",
             render: true,
+            optional: false,
+          },
+          {
+            name: "copy",
+            type: "bool",
+            options: [true, false],
+            defaultValue: true,
+            render: true,
+            optional: true,
+          },
+          {
+            name: "errors",
+            type: "select",
+            options: ['raise', 'ignore'],
+            defaultValue: 'raise',
+            render: true,
+            optional: true,
           },
         ],
     },
@@ -163,15 +193,11 @@ export const preprocessingTechniques = [
         name: "Round Data",
         value: "Round Data",
         parameters: [
-          {
-            name: "columns",
-            type: "columnList",
-            render: true,
-          },
           {
             name: "decimals",
-            type: "number",
+            type: "dict",
             render: true,
+            optional: false,
           },
         ],
     },
@@ -183,16 +209,13 @@ export const preprocessingTechniques = [
             name: "items",
             type: "list",
             render: true,
+            optional: true,  //check
           },
           {
             name: "like",
             type: "string",
             render: true,
-          },
-          {
-            name: "regex",
-            type: "string",
-            render: true,
+            optional: true, //check
           },
           {
             name: "axis",
@@ -200,6 +223,7 @@ export const preprocessingTechniques = [
             options: [0, 1, 'None'],
             default: 'None',
             render: true,
+            optional: true, //check
           },
         ],
     },
@@ -211,11 +235,13 @@ export const preprocessingTechniques = [
             name: "before",
             type: "any",  //date | str | int (column name or index)
             render: true,
+            optional: false,
           },
           {
             name: "after",
             type: "any",  //date | str | int (column name or index)
             render: true,
+            optional: false,
           },
           {
             name: "axis",
@@ -223,6 +249,7 @@ export const preprocessingTechniques = [
             options: [0, 1, 'None'],
             default: 'None',
             render: true,
+            optional: false,
           },
           {
             name: "copy",
@@ -230,6 +257,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           }
         ],
     },
@@ -241,6 +269,7 @@ export const preprocessingTechniques = [
             name: "by",
             type: "columnList",  
             render: true,
+            optional: false,
           },
           {
             name: "ascending",
@@ -248,6 +277,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "axis",
@@ -255,6 +285,7 @@ export const preprocessingTechniques = [
             options: [0, 1],
             default: 0,
             render: true,
+            optional: true,
           },
           {
             name: "inplace",
@@ -262,6 +293,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: false,
             render: true,
+            optional: true,
           },
           {
             name: "kind",
@@ -269,6 +301,7 @@ export const preprocessingTechniques = [
             options: ["quicksort", "mergesort", "heapsort", "stable"],
             default: "quicksort",
             render: true,
+            optional: true,
           },
           {
             name: "na_position",
@@ -276,6 +309,7 @@ export const preprocessingTechniques = [
             options: ["first", "last"],
             default: "last",
             render: true,
+            optional: true,
           },
           {
             name: "ignore_index",
@@ -283,6 +317,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: false,
             render: true,
+            optional: true,
           },          
         ],
     },
@@ -298,12 +333,14 @@ export const preprocessingTechniques = [
             name: "columns",
             type: "columnList", 
             render: true,
+            optional: false,
           },
           {
             name: "feature_range",
             type: "tuple", //(min,max)
             default: '(0, 1)', 
             render: true,
+            optional: true,
           },
           {
             name: "copy",
@@ -311,6 +348,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "clip",
@@ -318,6 +356,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: false,
             render: true,
+            optional: true,
           },
         ],
     },
@@ -329,6 +368,7 @@ export const preprocessingTechniques = [
             name: "columns",
             type: "columnList", 
             render: true,
+            optional: false,
           },
           {
             name: "copy",
@@ -336,6 +376,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           
         ],
@@ -348,6 +389,7 @@ export const preprocessingTechniques = [
             name: "column",
             type: "columnName", 
             render: true,
+            optional: false,
           },
           {
             name: "with_centering",
@@ -355,6 +397,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "with_scaling",
@@ -362,6 +405,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "copy",
@@ -369,6 +413,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "unit_variance",
@@ -376,12 +421,14 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: false,
             render: true,
+            optional: true,
           },
           {
             name: "quantile_range",
             type: "tuple", 
             default: '(25.0,75.0)',
             render: true,
+            optional: true,
           },
         ],
     },
@@ -393,6 +440,7 @@ export const preprocessingTechniques = [
             name: "column",
             type: "columnName", 
             render: true,
+            optional: false,
           },
           {
             name: "copy",
@@ -400,6 +448,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "with_mean",
@@ -407,6 +456,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           {
             name: "with_std",
@@ -414,6 +464,7 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
           },
           
         ],
@@ -426,6 +477,7 @@ export const preprocessingTechniques = [
             name: "column",
             type: "columnName", 
             render: true,
+            optional: false,
           },
           {
             name: "norm",
@@ -433,24 +485,42 @@ export const preprocessingTechniques = [
             options: ['l1','l2','max'],
             default: "l2",
             render: true,
+            optional: true,
           },
+          {
+            name: "copy",
+            type: "bool", 
+            options: [true, false],
+            default: true,
+            render: true,
+            optional: true,
+          },
+
         ],
     },
     {
         name: "Ordinal Encoding",
         value: "Ordinal Encoding",
         parameters: [
+          {
+            name: "columns",
+            type: "columnList",   
+            render: true,
+            optional: false,
+          },
           {
             name: "categories",
             type: "list", //or auto  
             default: 'auto',
             render: true,
+            optional: true,
           },
           {
             name: "dtype",
             type: "str", 
             default: "np.float64",
             render: true,
+            optional: true,
           },
           {
             name: "handle_unknown",
@@ -458,18 +528,21 @@ export const preprocessingTechniques = [
             options: ['error', 'use_encoded_value'],
             default: 'error',
             render: true,
+            optional: true,
           },
           {
             name: "unknown_value",  //for 'use_encoded_value'
             type: "int", //int | np.nan 
             default: 'None',
             render: true,
+            optional: true,
           },
           {
             name: "encoded_missing_value",  
             type: "int", //int | np.nan 
             default: 'np.nan',
             render: true,
+            optional: true,
           },
         ],
     },
@@ -478,29 +551,32 @@ export const preprocessingTechniques = [
         value: "One Hot Encoding",
         parameters: [
           {
-            name: "n_values",
-            type: "any", //auto | int | array  
+            name: "columns",
+            type: "columnList",   
+            render: true,
+            optional: false,
+          },
+          {
+            name: "categories",
+            type: "list", //or auto  
             default: 'auto',
             render: true,
+            optional: true,
           },
           {
             name: "dtype",
             type: "str", 
             default: "np.float",
             render: true,
+            optional: true,
           },
           {
             name: "handle_unknown",
             type: "select", 
-            options: ['error', 'ignore'],
+            options: ['error', 'ignore','infrequent_if_exist'],
             default: 'error',
             render: true,
-          },
-          {
-            name: "categorical_features",  
-            type: "list", // or all 
-            default: 'all',
-            render: true,
+            optional: true,
           },
           {
             name: "sparse",  
@@ -508,6 +584,21 @@ export const preprocessingTechniques = [
             options: [true, false],
             default: true,
             render: true,
+            optional: true,
+          },
+          {
+            name: "min_frequency",  
+            type: "float",
+            default: 'None',
+            render: true,
+            optional: true,
+          },
+          {
+            name: "max_categories",  
+            type: "integer",
+            default: 'None',
+            render: true,
+            optional: true,
           },
         ],
     },
