@@ -1,6 +1,6 @@
 from re import sub
 import sklearn
-import lightgbm as lgb
+# import lightgbm as lgb
 import xgboost as xgb
 
 def logistic_regression(**params):
@@ -39,9 +39,9 @@ def gradient_boosting(**params):
     model = sklearn.ensemble.GradientBoostingClassifier(**params["parameters"])
     return model
 
-def lgbm(**params):
-    model = lgb.LGBMClassifier(**params["parameters"])
-    return model
+# def lgbm(**params):
+#     model = lgb.LGBMClassifier(**params["parameters"])
+#     return model
 
 def xgboost(**params):
     model = xgb.XGBClassifier(**params["parameters"])
